from argparse import ArgumentParser, Namespace

from ghAllIssues.libs.ghAllIssues import getGHIssues
from ghAllIssues.libs.graph import main as graphMain


def get_argparse() -> Namespace:
    parser: ArgumentParser = ArgumentParser(
        prog="GH All issues",
        usage="This program generates an interval tree from a JSON file containing a GitHub repositories issues.",
    )
    parser.add_argument(
        "-r",
        "--repository",
        help='GitHub repository to be used. Format needs to be "OWNER/REPO". Default is numpy/numpy',
        default="numpy/numpy",
        type=str,
        required=False,
    )

    parser.add_argument(
        "-s",
        "--save-json",
        help="Save analysis to JSON file. EX: --save-json=issues.json",
        default="issues.json",
        type=str,
        required=True,
    )

    parser.add_argument(
        "-t",
        "--token",
        help="GitHub personal access token",
        type=str,
        required=True,
    )

    return parser.parse_args()


def main() -> None:
    args: Namespace = get_argparse()

    print(
        getGHIssues(
            repo=args.repository,
            token=args.token,
            filename=args.save_json,
        )
    )

    graphMain(jsonFile=args.save_json)


if __name__ == "__main__":
    main()



from argparse import ArgumentParser, Namespace

import pandas
from pandas import DataFrame


def get_argparse() -> ArgumentParser:
    parser: ArgumentParser = ArgumentParser(
        prog="Convert Output",
        usage="This program converts a JSON file into various different formats.",
    )
    parser.add_argument(
        "-i",
        "--input",
        help="The input JSON file that is to be converted",
        type=str,
        required=True,
    )
    parser.add_argument(
        "--csv",
        help="Flag to set the output of the conversion to a .csv file",
        required=False,
        action="store_true",
    )
    parser.add_argument(
        "--tsv",
        help="Flag to set the output of the conversion to a .tsv file",
        required=False,
        action="store_true",
    )
    return parser


def createDataFrame(filename: str) -> DataFrame:
    return pandas.read_json(filename)


def convertToCSV(df: DataFrame, filename: str) -> None:
    df.to_csv(filename, index=False)


def convertToTSV(df: DataFrame, filename: str) -> None:
    df.to_csv(filename, sep="\t", index=False)

def main():
    args: Namespace = get_argparse().parse_args()

    if args.csv is None and args.tsv is None:
        print('Run "python convertOutput -h" for a full list of arguements...')
        quit(1)

    filename: str = args.input
    df: DataFrame = createDataFrame(filename=filename)

    filenamePrefix: str = filename.split(".json")[0]

    if args.csv:
        convertToCSV(df, filename=filenamePrefix + ".csv")

    if args.tsv:
        convertToTSV(df, filename=filenamePrefix + ".tsv")

if __name__ == "__main__":
    main()




# setup.py - placeholder for eventual setup script

from setuptools import setup

from ssl_metrics import version

setup(
    name="ssl-metrics-github-issues",
    packages=["ssl_metrics"],
    version=version.version(),
    description="SSL Metrics - GitHub Issues Analysis",
    author="Software and Systems Laboratory - Loyola University Chicago",
    author_email="ssl-metrics@ssl.luc.edu",
    license="Apache License 2.0",
    url="https://ssl.cs.luc.edu/projects/metricsDashboard",
    keywords=["github", "software engineering", "metrics", "issues"],
    classifiers=[
        "Development Status :: 4 - Beta",
        "Programming Language :: Python :: 3.0",
        "License :: OSI Approved :: Apache Software License",
    ],
    python_requires=">=3",
    install_requires=[
        "intervaltree",
        "numpy",
        "matplotlib",
        "pandas",
        "progress",
        "python-dateutil",
        "requests",
    ],
    entry_points={"console_scripts": [
        "ssl-metrics-github-issues-collect = ssl_metrics.github_issues:main",
        "ssl-metrics-github-issues-convert = ssl_metrics.convert_output:main"
        "ssl-metrics-github-issues-graph = ssl_metrics.create_graph:main"
        ]
    },
)
